#!/bin/bash
# Script used as entrypoint for Legacy environments.
set -e
declare -A env_api_ids
declare -A env_peering_maps
declare -A env_identity_gateway_internal_hostname
declare -A env_public_urls
declare -A env_csp_service_def_map
declare -A env_csp_service_instance_map
declare -A env_csp_service_instance_csr_map
declare -A env_csp_client_id_map
declare -A env_csp_service_ticker_map
ENV=${ENV:-localdev}

env_api_ids=(
  ["localdev"]="ACCESS_SERVICE_CONNECTOR_ID"
  ["dev01"]="81KGDVTZJU"
  ["dev08"]="WW8ZF3P8KK"
  ["test03"]="TG9H9KZ8CU"
  ["hub02"]="81KGDVTZJU"
  ["hub-dev-us"]="81KGDVTZJU"
  ["hub04"]="TG9H9KZ8CU"
  ["hub-prod-us"]="M6RQWVKJ7V"
  ["hub-prod-eu"]="NU8NK98URP"
  ["hub-prod-ap"]="KBI3NYMWD8"
  ["hub-prod-ap2"]="UDNJR6JDFC"
  ["eap01"]="M6RQWVKJ7V"
  ["prod01"]="21VCMMGB7G"
  ["prod02"]="7I2PQH458I"
  ["prod04"]="94IV2MMA8D"
  ["prod05"]="GKB49FI3Z2"
  ["prod06"]="NU8NK98URP"
  ["prodnrt"]="KBI3NYMWD8"
  ["prodsyd"]="UDNJR6JDFC"
)

env_peering_maps=(
  ["localdev"]="localdev"
  ["dev01"]="dev01"
  ["dev08"]="dev08"
  ["test03"]="test03"
  ["hub02"]="hub02,dev01"
  ["hub-dev-us"]="hub-dev-us,dev01"
  ["hub04"]="hub04,test03"
  ["hub-prod-us"]="hub-prod-us,eap01,prod01,prod02,prod04,prod05"
  ["hub-prod-eu"]="hub-prod-eu,prod06"
  ["hub-prod-ap"]="hub-prod-ap,prodnrt"
  ["hub-prod-ap2"]="hub-prod-ap2,prodsyd"
  ["eap01"]="eap01"
  ["prod01"]="prod01"
  ["prod02"]="prod02"
  ["prod04"]="prod04"
  ["prod05"]="prod05"
  ["prod06"]="prod06"
  ["prodnrt"]="prodnrt"
  ["prodsyd"]="prodsyd"
)

env_identity_gateway_internal_hostname=(
  ["hub-dev-us"]="kcdev01-internal.cbc-eng.vmware.com"
  ["hub04"]="kctest03-internal.cbc-eng.vmware.com"
  ["hub-prod-us"]="use1-internal.carbonblackcloud.vmware.com"
  ["hub-prod-eu"]="ec1-internal.carbonblackcloud.vmware.com"
  ["hub-prod-ap"]="apne1-internal.carbonblackcloud.vmware.com"
  ["hub-prod-ap2"]="apse2-internal.carbonblackcloud.vmware.com"
)

env_public_urls=(
  ["localdev"]="localhost:8900"
  ["dev01"]="defense-dev01.cbdtest.io"
  ["dev08"]="defense-dev08.cbdtest.io"
  ["test03"]="defense-test03.cbdtest.io"
  ["eap01"]="defense-eap01.conferdeploy.net"
  ["prod01"]="dashboard.confer.net"
  ["prod02"]="defense.conferdeploy.net"
  ["prod04"]="blackrock.confer.net"
  ["prod05"]="defense-prod05.conferdeploy.net"
  ["prod06"]="defense-eu.conferdeploy.net"
  ["prodnrt"]="defense-prodnrt.conferdeploy.net"
  ["prodsyd"]="defense-prodsyd.conferdeploy.net"
)

env_csp_service_def_map=(
  ["localdev"]="localdev"
  ["dev01"]="70539df3-4c23-41a3-b214-26c96f261b13"
  ["test03"]="70539df3-4c23-41a3-b214-26c96f261b13"
  ["hub-dev-us"]="70539df3-4c23-41a3-b214-26c96f261b13"
  ["hub04"]="70539df3-4c23-41a3-b214-26c96f261b13"
  ["hub-prod-us"]="78962d09-1571-4db1-b9a0-1bdb69045252"
  ["hub-prod-eu"]="78962d09-1571-4db1-b9a0-1bdb69045252"
  ["hub-prod-ap"]="78962d09-1571-4db1-b9a0-1bdb69045252"
  ["hub-prod-ap2"]="78962d09-1571-4db1-b9a0-1bdb69045252"
  ["eap01"]=""
  ["prod01"]=""
  ["prod02"]=""
  ["prod05"]="78962d09-1571-4db1-b9a0-1bdb69045252"
  ["prod06"]="78962d09-1571-4db1-b9a0-1bdb69045252"
  ["prodnrt"]="78962d09-1571-4db1-b9a0-1bdb69045252"
  ["prodsyd"]="78962d09-1571-4db1-b9a0-1bdb69045252"
)
env_csp_service_ticker_map=(
  ["localdev"]="localdev"
  ["dev01"]="cbcdv"
  ["test03"]="cbcdv"
  ["hub-dev-us"]="cbcdv"
  ["hub04"]="cbcdv"
  ["hub-prod-us"]="cbc"
  ["hub-prod-eu"]="cbc"
  ["hub-prod-ap"]="cbc"
  ["hub-prod-ap2"]="cbc"
  ["eap01"]=""
  ["prod01"]=""
  ["prod02"]=""
  ["prod05"]="cbc"
  ["prod06"]="cbc"
  ["prodnrt"]="cbc"
  ["prodsyd"]="cbc"
)

env_csp_service_instance_map=(
  ["localdev"]="localdev"
  ["dev01"]="4ff11a73-c7e8-4ebf-ab4c-e8555c6cc78e"
  ["test03"]="2f38dd9c-3366-4073-a6c6-9bae1ce166c1"
  ["hub-dev-us"]="4ff11a73-c7e8-4ebf-ab4c-e8555c6cc78e"
  ["hub04"]="2f38dd9c-3366-4073-a6c6-9bae1ce166c1"
  ["hub-prod-us"]="6b3d1604-8ef1-451d-ad7c-da29ed950832"
  ["hub-prod-eu"]="d1177d25-2c0b-4d76-88f5-3e8af5afe67a"
  ["hub-prod-ap"]="a06c3106-7fe5-4022-b5b1-bb0959f52bc1"
  ["hub-prod-ap2"]="0adfeb15-dd47-4409-b37c-3ab6e530d1b1"
  ["eap01"]=""
  ["prod01"]=""
  ["prod02"]=""
  ["prod05"]="6b3d1604-8ef1-451d-ad7c-da29ed950832"
  ["prod06"]="d1177d25-2c0b-4d76-88f5-3e8af5afe67a"
  ["prodnrt"]="a06c3106-7fe5-4022-b5b1-bb0959f52bc1"
  ["prodsyd"]="0adfeb15-dd47-4409-b37c-3ab6e530d1b1"
)

env_csp_service_instance_csr_map=(
  ["localdev"]="localdev"
  ["dev01"]="534f27a0-f1ad-4904-9fbd-dba6e66d6c7b"
  ["test03"]="fe57a52f-fce3-4193-8d95-745fe98483a5"
  ["hub-dev-us"]="534f27a0-f1ad-4904-9fbd-dba6e66d6c7b"
  ["hub04"]="fe57a52f-fce3-4193-8d95-745fe98483a5"
  ["hub-prod-us"]="4cfd3f5a-372f-4ace-9828-ba32334eec3b"
  ["hub-prod-eu"]="88b5ea1c-0ef0-462f-b286-d972ed7ed892"
  ["hub-prod-ap"]="92f2657c-4acf-4176-b428-d38c85570ed4"
  ["hub-prod-ap2"]="cd9b3f12-40f4-4bbb-99eb-a32609ac013c"
  ["eap01"]=""
  ["prod01"]=""
  ["prod02"]=""
  ["prod05"]="4cfd3f5a-372f-4ace-9828-ba32334eec3b"
  ["prod06"]="88b5ea1c-0ef0-462f-b286-d972ed7ed892"
  ["prodnrt"]="92f2657c-4acf-4176-b428-d38c85570ed4"
  ["prodsyd"]="cd9b3f12-40f4-4bbb-99eb-a32609ac013c"
)

env_csp_client_id_map=(
  ["localdev"]="localdev"
  ["dev01"]="B04kJ17yTPbkQ1lUEHDE6f6c82FX8X1FhPb"
  ["test03"]="QkVX2s7JmwAd7SZMyOWRgZSQRMKE6blY4IS"
  ["hub-dev-us"]="B04kJ17yTPbkQ1lUEHDE6f6c82FX8X1FhPb"
  ["hub04"]="QkVX2s7JmwAd7SZMyOWRgZSQRMKE6blY4IS"
  ["hub-prod-us"]="gKionQ3EXvE8ZnbTXOXfGDfFadC3azCkhit"
  ["hub-prod-eu"]="yulavUzkI8ytcIErvQeKTMoR3iPHua8k5Jo"
  ["hub-prod-ap"]="dWxX0eHMzGT4jCifyKPuPSOUkpbXEYfnXCb"
  ["hub-prod-ap2"]="e0GD7k52AzNSh08i3GPLR82UZFhJwOWH1Wq"
  ["eap01"]=""
  ["prod01"]="gKionQ3EXvE8ZnbTXOXfGDfFadC3azCkhit"
  ["prod02"]="gKionQ3EXvE8ZnbTXOXfGDfFadC3azCkhit"
  ["prod05"]="gKionQ3EXvE8ZnbTXOXfGDfFadC3azCkhit"
  ["prod06"]="yulavUzkI8ytcIErvQeKTMoR3iPHua8k5Jo"
  ["prodnrt"]="dWxX0eHMzGT4jCifyKPuPSOUkpbXEYfnXCb"
  ["prodsyd"]="e0GD7k52AzNSh08i3GPLR82UZFhJwOWH1Wq"
)

mixed_envs="dev01,hub-dev-us,test03,hub04,prod05,hub-prod-us,prod06,hub-prod-eu,prodsyd,hub-prod-ap,prodnrt,hub-prod-ap2"

export ACCESS_SERVICE_API_ENVS=${env_peering_maps[$ENV]}
export ACCESS_METRICS_TOKEN=$METRICS_TOKEN
export ACCESS_METRICS_ENVIRONMENT=$ENV
export MIXED_ENVS=${mixed_envs}

if [ "${ENV}" == "localdev" ]; then
    # Set default only for localdev so access to mockaws is seamless
    export AWS_REGION="us-east-1"
    export ACCESS_DYNAMODB_ENDPOINT=https://access-mockaws:4569
    export ACCESS_DYNAMODB_REGION=$AWS_REGION

    export SECOPS_S3_BUCKET_NAME="secops-grants-csv"
    export SECOPS_S3_REGION=$AWS_REGION
    export ACCESS_S3_ENDPOINT=https://mockaws:4572
    export ACCESS_SERVICE_API_IDS="ACCESS_SERVICE_CONNECTOR_ID"
    export ACCESS_SERVICE_API_SECRETS="ACCESS_SERVICE_CONNECTOR_SECRET"

    export GATEWAY_PUBLIC_URLS="localhost:8900"
    export GATEWAY_INTERNAL_ADDRESS="psc.gateway:8900"

    # Temporarily configure cache expirations to 30 min for local containers
    export CACHE_PERMITTED_TTL=1800
    export CACHE_ROLE_PERMISSIONS_TTL=1800
else
    export AWS_DEFAULT_REGION=$(curl 169.254.169.254/latest/meta-data/placement/availability-zone/ | python -c "import json,sys;val=sys.stdin.read()[:-1];print(val);") || exit 1
    export ACCESS_DYNAMODB_REGION=$AWS_DEFAULT_REGION
    export ACCESS_DYNAMODB_TABLE_PREFIX=${DB_ENV}

    for env_name in  $(echo "${ACCESS_SERVICE_API_ENVS}" | sed "s/,/ /g")
    do
        env_secret=$(aws ssm get-parameter --name "/$env_name/accessServiceApi.secret" --with-decryption | python -c "import json,sys;val=json.load(sys.stdin)['Parameter']['Value'];print(val);")  || exit 1
        ACCESS_SERVICE_API_SECRETS="$ACCESS_SERVICE_API_SECRETS,$env_secret"
        ACCESS_SERVICE_API_IDS="$ACCESS_SERVICE_API_IDS,${env_api_ids[$env_name]}"
        if [[ -v env_public_urls[$env_name] ]]; then
            echo "public gateway URL: ${env_public_urls[$env_name]}"
            GATEWAY_PUBLIC_URLS="$GATEWAY_PUBLIC_URLS,${env_public_urls[$env_name]}"
        fi
    done

    export SECOPS_S3_REGION=$AWS_DEFAULT_REGION
    export ACCESS_SERVICE_API_SECRETS=$(echo $ACCESS_SERVICE_API_SECRETS | sed 's/,//')
    export ACCESS_SERVICE_API_IDS=$(echo $ACCESS_SERVICE_API_IDS | sed 's/,//')

    export GATEWAY_PUBLIC_URLS=$(echo $GATEWAY_PUBLIC_URLS | sed 's/,//')
    export GATEWAY_INTERNAL_ADDRESS="gateway.psc.internal:8903"

    # only log to secops S3 bucket for prod envs
    if [[ ! "$ENV" =~ (dev|test|hub02|hub-dev-us|hub04).* ]]; then
        export SECOPS_AWS_ACCESS_KEY="AKIAI7XZM4DZLDUKAEVA"
        export SECOPS_AWS_SECRET_KEY=$(aws ssm get-parameter --name "/$ENV/secops.aws.secret" --with-decryption | python -c "import json,sys;val=json.load(sys.stdin)['Parameter']['Value'];print(val);") || exit 1

        if [[ "$ENV" =~ (prodsyd|hub-prod-ap2).* ]]; then
            export SECOPS_S3_BUCKET_NAME="cb-defense-ap2-csr-logs"
        elif [[ "$ENV" =~ (prodnrt|hub-prod-ap).* ]]; then
            export SECOPS_S3_BUCKET_NAME="cb-defense-ap-csr-logs"
        elif [[ "$ENV" =~ (prod06|hub-prod-eu).* ]]; then
            export SECOPS_S3_BUCKET_NAME="cb-defense-eu-csr-logs"
        elif [[ "$ENV" =~ (eap|prod|hub-prod).* ]]; then
            export SECOPS_S3_BUCKET_NAME="cb-defense-csr-logs"
        fi
        echo "Using SECOPS BUCKET=$SECOPS_S3_BUCKET_NAME"

    else
        export SECOPS_S3_BUCKET_NAME="secops-grants-csv"
        export SECOPS_AWS_ACCESS_KEY=
        export SECOPS_AWS_SECRET_KEY=
    fi

    # cache warmer enabled in all prod
    export CACHE_ROLE_WARMER_ENABLED=true

    java_extra_ops=" -Dmanagement.metrics.export.wavefront.enabled=true"
    java_extra_ops="${java_extra_ops} -Dmanagement.metrics.export.wavefront.uri=proxy://${ENV}-wavefront-proxy.cbd.internal:2881"

    export JAVA_EXTRA_OPS="${java_extra_ops}"

    if [[ "$mixed_envs" == *"$ENV"* ]]; then
        # Exporting config for CSP Resources
        export CSP_ENABLED=true
        export ACCESS_PERMISSION_CACHE_USESSL=true
        export ACCESS_PERMISSION_CACHE_ENABLED=true
        export CSP_SERVICE_ID=${env_csp_service_def_map[$ENV]}
        export CSP_SERVICE_TICKER=${env_csp_service_ticker_map[$ENV]}
        export CSP_SERVICE_INSTANCE_ID=${env_csp_service_instance_map[$ENV]}
        export CSP_SERVICE_INSTANCE_ID_CSR=${env_csp_service_instance_csr_map[$ENV]}

        env_csp_client_secret=$(aws ssm get-parameter --name "/$env_name/accessCSPClient.secret" --with-decryption | python -c "import json,sys;val=json.load(sys.stdin)['Parameter']['Value'];print(val);")  || exit 1
        export CSP_AUTH_CLIENT_ID="${env_csp_client_id_map[$ENV]}"
        export CSP_AUTH_CLIENT_SECRET="${env_csp_client_secret}"
        export IDENTITY_GATEWAY_INTERNAL_HOSTNAME="${env_identity_gateway_internal_hostname[$ENV]}"

        # If the current env is dev - use CSP staging
        # otherwise - use CSP prod
        if [[ "$ENV" =~ (dev01|test03|hub-dev-us|hub04).* ]]; then
          export CSP_URL="https://console-stg.cloud.vmware.com"
        else
          export CSP_URL="https://console.cloud.vmware.com"
        fi
    fi
fi

echo "Using AWS_DEFAULT_REGION=$AWS_DEFAULT_REGION"

exec "$@"
